==> open-cluster-management-observability-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta1/ObservabilityAddonStatusBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ObservabilityAddonStatusBuilder extends ObservabilityAddonStatusFluentImpl<ObservabilityAddonStatusBuilder> implements VisitableBuilder<ObservabilityAddonStatus,ObservabilityAddonStatusBuilder>{
  public ObservabilityAddonStatusBuilder() {
    this(false);
  }
  public ObservabilityAddonStatusBuilder(Boolean validationEnabled) {
    this(new ObservabilityAddonStatus(), validationEnabled);
  }
  public ObservabilityAddonStatusBuilder(ObservabilityAddonStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ObservabilityAddonStatusBuilder(ObservabilityAddonStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ObservabilityAddonStatus(), validationEnabled);
  }
  public ObservabilityAddonStatusBuilder(ObservabilityAddonStatusFluent<?> fluent,ObservabilityAddonStatus instance) {
    this(fluent, instance, false);
  }
  public ObservabilityAddonStatusBuilder(ObservabilityAddonStatusFluent<?> fluent,ObservabilityAddonStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withConditions(instance.getConditions());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ObservabilityAddonStatusBuilder(ObservabilityAddonStatus instance) {
    this(instance,false);
  }
  public ObservabilityAddonStatusBuilder(ObservabilityAddonStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withConditions(instance.getConditions());
    }
    this.validationEnabled = validationEnabled; 
  }
  ObservabilityAddonStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ObservabilityAddonStatus build() {
    ObservabilityAddonStatus buildable = new ObservabilityAddonStatus(fluent.getConditions());
    return buildable;
  }
  
}

==> open-cluster-management-observability-model-6.8.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta1/ObservabilityAddonStatusBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ObservabilityAddonStatusBuilder extends ObservabilityAddonStatusFluent<ObservabilityAddonStatusBuilder> implements VisitableBuilder<ObservabilityAddonStatus,ObservabilityAddonStatusBuilder>{
  public ObservabilityAddonStatusBuilder() {
    this(false);
  }
  public ObservabilityAddonStatusBuilder(Boolean validationEnabled) {
    this(new ObservabilityAddonStatus(), validationEnabled);
  }
  public ObservabilityAddonStatusBuilder(ObservabilityAddonStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ObservabilityAddonStatusBuilder(ObservabilityAddonStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ObservabilityAddonStatus(), validationEnabled);
  }
  public ObservabilityAddonStatusBuilder(ObservabilityAddonStatusFluent<?> fluent,ObservabilityAddonStatus instance) {
    this(fluent, instance, false);
  }
  public ObservabilityAddonStatusBuilder(ObservabilityAddonStatusFluent<?> fluent,ObservabilityAddonStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ObservabilityAddonStatus());

    if (instance != null) {
      fluent.withConditions(instance.getConditions());
      fluent.withConditions(instance.getConditions());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ObservabilityAddonStatusBuilder(ObservabilityAddonStatus instance) {
    this(instance,false);
  }
  public ObservabilityAddonStatusBuilder(ObservabilityAddonStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ObservabilityAddonStatus());

    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withConditions(instance.getConditions());
    }
    this.validationEnabled = validationEnabled; 
  }
  ObservabilityAddonStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ObservabilityAddonStatus build() {
    ObservabilityAddonStatus buildable = new ObservabilityAddonStatus(fluent.buildConditions());
    return buildable;
  }
  
}
